### <a name="manual"></a> Decoration block

Inserts table of content calculated from chapter blocks.

| Key       |      Description      | Default |
|:----------|:--------------------- |:----- |
| type      |  stickToBottom                 |  
| content   |  content to be sticked to bottom    |  




Example:
```YAML
- type       : stickToBottom
  content    : 'Some text'
```

Back to [Documentation](../../../README.md#block_structure)
